@@ -30,7 +30,7 @@ class ForumListingBreadcrumbBuilder extends ForumBreadcrumbBuilderBase {
     $term_id = $term->id();
     $breadcrumb->addCacheableDependency($term);
 
-    $parents = $this->forumManager->getParents($term_id);
+    $parents = $this->termStorage->loadAllParents($term_id);
     if ($parents) {
       foreach (array_reverse($parents) as $parent) {
         if ($parent->id() != $term_id) {
