@@ -1,13 +1,9 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\Tests\hal\Unit\FieldNormalizerDenormalizeExceptionsUnitTest.
- */
-
 namespace Drupal\Tests\hal\Unit;
 
 use Drupal\hal\Normalizer\FieldNormalizer;
+use Symfony\Component\Serializer\Exception\InvalidArgumentException;
 
 /**
  * @coversDefaultClass \Drupal\hal\Normalizer\FieldNormalizer
@@ -22,12 +18,12 @@ class FieldNormalizerDenormalizeExceptionsUnitTest extends NormalizerDenormalize
    *   Context for FieldNormalizer::denormalize().
    *
    * @dataProvider providerNormalizerDenormalizeExceptions
-   * @expectedException \Symfony\Component\Serializer\Exception\InvalidArgumentException
    */
   public function testFieldNormalizerDenormalizeExceptions($context) {
     $field_item_normalizer = new FieldNormalizer();
-    $data = array();
-    $class = array();
+    $data = [];
+    $class = [];
+    $this->setExpectedException(InvalidArgumentException::class);
     $field_item_normalizer->denormalize($data, $class, NULL, $context);
   }
 
