@@ -24,6 +24,18 @@ class MediaCacheTagsTest extends EntityWithUriCacheTagsTestBase {
     'media_test_source',
   ];
 
+  /**
+   * {@inheritdoc}
+   */
+  protected function setUp() {
+    parent::setUp();
+    \Drupal::configFactory()
+      ->getEditable('media.settings')
+      ->set('standalone_url', TRUE)
+      ->save(TRUE);
+    $this->container->get('router.builder')->rebuild();
+  }
+
   /**
    * {@inheritdoc}
    */
