@@ -67,8 +67,7 @@ class EntityRevisionTest extends UnitTestCase {
   public function testGetEntityDestinationValues() {
     $destination = $this->getEntityRevisionDestination([]);
     // Return a dummy because we don't care what gets called.
-    $entity = $this->prophesize('\Drupal\Core\Entity\EntityInterface')
-      ->willImplement('\Drupal\Core\Entity\RevisionableInterface');
+    $entity = $this->prophesize('\Drupal\Core\Entity\RevisionableInterface');
     // Assert that the first ID from the destination values is used to load the
     // entity.
     $this->storage->loadRevision(12)
@@ -85,8 +84,7 @@ class EntityRevisionTest extends UnitTestCase {
    */
   public function testGetEntityUpdateRevision() {
     $destination = $this->getEntityRevisionDestination([]);
-    $entity = $this->prophesize('\Drupal\Core\Entity\EntityInterface')
-      ->willImplement('\Drupal\Core\Entity\RevisionableInterface');
+    $entity = $this->prophesize('\Drupal\Core\Entity\RevisionableInterface');
 
     $entity_type = $this->prophesize('\Drupal\Core\Entity\EntityTypeInterface');
     $entity_type->getKey('id')->willReturn('nid');
@@ -113,8 +111,7 @@ class EntityRevisionTest extends UnitTestCase {
    */
   public function testGetEntityNewRevision() {
     $destination = $this->getEntityRevisionDestination([]);
-    $entity = $this->prophesize('\Drupal\Core\Entity\EntityInterface')
-      ->willImplement('\Drupal\Core\Entity\RevisionableInterface');
+    $entity = $this->prophesize('\Drupal\Core\Entity\RevisionableInterface');
 
     $entity_type = $this->prophesize('\Drupal\Core\Entity\EntityTypeInterface');
     $entity_type->getKey('id')->willReturn('nid');
