@@ -130,7 +130,7 @@ class NodeViewBuilder extends EntityViewBuilder {
         'title' => t('Read more<span class="visually-hidden"> about @title</span>', [
           '@title' => $node_title_stripped,
         ]),
-        'url' => $entity->urlInfo(),
+        'url' => $entity->toUrl(),
         'language' => $entity->language(),
         'attributes' => [
           'rel' => 'tag',
