@@ -121,8 +121,7 @@ class EntityResource extends ResourceBase implements DependentPluginInterface {
    *
    * @throws \Symfony\Component\HttpKernel\Exception\HttpException
    */
-  public function get(EntityInterface $entity) {
-    $request = \Drupal::request();
+  public function get(EntityInterface $entity, Request $request) {
     $response = new ResourceResponse($entity, 200);
     // @todo Either remove the line below or remove this todo in https://www.drupal.org/project/drupal/issues/2973356
     $response->addCacheableDependency($request->attributes->get(AccessAwareRouterInterface::ACCESS_RESULT));
@@ -190,7 +189,7 @@ class EntityResource extends ResourceBase implements DependentPluginInterface {
       // metadata here.
       $headers = [];
       if (in_array('canonical', $entity->uriRelationships(), TRUE)) {
-        $url = $entity->urlInfo('canonical', ['absolute' => TRUE])->toString(TRUE);
+        $url = $entity->toUrl('canonical', ['absolute' => TRUE])->toString(TRUE);
         $headers['Location'] = $url->getGeneratedUrl();
       }
       return new ModifiedResourceResponse($entity, 201, $headers);
