@@ -80,6 +80,20 @@ class ThemeTest extends BrowserTestBase {
     $this->assertTrue(in_array('page__front', $suggestions), 'Front page template was suggested.');
   }
 
+  /**
+   * Tests theme can provide classes.
+   */
+  public function testClassLoading() {
+    // Install test theme and set it as default.
+    $this->config('system.theme')
+      ->set('default', 'test_theme')
+      ->save();
+    $this->resetAll();
+    // Visit page controller and confirm that the theme class is loaded.
+    $this->drupalGet('/theme-test/test-theme-class');
+    $this->assertText('Loading ThemeClass was successful.');
+  }
+
   /**
    * Ensures a theme's .info.yml file is able to override a module CSS file from being added to the page.
    *
