@@ -30,7 +30,7 @@ class PathElementFormTest extends KernelTestBase implements FormInterface {
    *
    * @var array
    */
-  public static $modules = array('system', 'user');
+  public static $modules = ['system', 'user'];
 
   /**
    * Sets up the test.
@@ -41,16 +41,16 @@ class PathElementFormTest extends KernelTestBase implements FormInterface {
     $this->installEntitySchema('user');
     \Drupal::service('router.builder')->rebuild();
     /** @var \Drupal\user\RoleInterface $role */
-    $role = Role::create(array(
+    $role = Role::create([
       'id' => 'admin',
       'label' => 'admin',
-    ));
+    ]);
     $role->grantPermission('link to any page');
     $role->save();
-    $this->testUser = User::create(array(
+    $this->testUser = User::create([
       'name' => 'foobar',
       'mail' => 'foobar@example.com',
-    ));
+    ]);
     $this->testUser->addRole($role->id());
     $this->testUser->save();
     \Drupal::service('current_user')->setAccount($this->testUser);
@@ -68,57 +68,57 @@ class PathElementFormTest extends KernelTestBase implements FormInterface {
    */
   public function buildForm(array $form, FormStateInterface $form_state) {
     // A required validated path.
-    $form['required_validate'] = array(
+    $form['required_validate'] = [
       '#type' => 'path',
       '#required' => TRUE,
       '#title' => 'required_validate',
       '#convert_path' => PathElement::CONVERT_NONE,
-    );
+    ];
 
     // A non validated required path.
-    $form['required_non_validate'] = array(
+    $form['required_non_validate'] = [
       '#type' => 'path',
       '#required' => TRUE,
       '#title' => 'required_non_validate',
       '#convert_path' => PathElement::CONVERT_NONE,
       '#validate_path' => FALSE,
-    );
+    ];
 
     // A non required validated path.
-    $form['optional_validate'] = array(
+    $form['optional_validate'] = [
       '#type' => 'path',
       '#required' => FALSE,
       '#title' => 'optional_validate',
       '#convert_path' => PathElement::CONVERT_NONE,
-    );
+    ];
 
     // A non required converted path.
-    $form['optional_validate'] = array(
+    $form['optional_validate'] = [
       '#type' => 'path',
       '#required' => FALSE,
       '#title' => 'optional_validate',
       '#convert_path' => PathElement::CONVERT_ROUTE,
-    );
+    ];
 
     // A converted required validated path.
-    $form['required_validate_route'] = array(
+    $form['required_validate_route'] = [
       '#type' => 'path',
       '#required' => TRUE,
       '#title' => 'required_validate_route',
-    );
+    ];
 
     // A converted required validated path.
-    $form['required_validate_url'] = array(
+    $form['required_validate_url'] = [
       '#type' => 'path',
       '#required' => TRUE,
       '#title' => 'required_validate_url',
       '#convert_path' => PathElement::CONVERT_URL,
-    );
+    ];
 
-    $form['submit'] = array(
+    $form['submit'] = [
       '#type' => 'submit',
       '#value' => t('Submit'),
-    );
+    ];
 
     return $form;
   }
@@ -154,19 +154,19 @@ class PathElementFormTest extends KernelTestBase implements FormInterface {
 
     // Valid form state.
     $this->assertEqual(count($form_state->getErrors()), 0);
-    $this->assertEqual($form_state->getValue('required_validate_route'), array(
+    $this->assertEqual($form_state->getValue('required_validate_route'), [
       'route_name' => 'entity.user.canonical',
-      'route_parameters' => array(
+      'route_parameters' => [
         'user' => $this->testUser->id(),
-      ),
-    ));
+      ],
+    ]);
     /** @var \Drupal\Core\Url $url */
     $url = $form_state->getValue('required_validate_url');
     $this->assertTrue($url instanceof Url);
     $this->assertEqual($url->getRouteName(), 'entity.user.canonical');
-    $this->assertEqual($url->getRouteParameters(), array(
+    $this->assertEqual($url->getRouteParameters(), [
       'user' => $this->testUser->id(),
-    ));
+    ]);
 
     // Test #required.
     $form_state = (new FormState())
@@ -179,7 +179,7 @@ class PathElementFormTest extends KernelTestBase implements FormInterface {
     $errors = $form_state->getErrors();
     // Should be missing 'required_validate' field.
     $this->assertEqual(count($errors), 1);
-    $this->assertEqual($errors, array('required_validate' => t('@name field is required.', array('@name' => 'required_validate'))));
+    $this->assertEqual($errors, ['required_validate' => t('@name field is required.', ['@name' => 'required_validate'])]);
 
     // Test invalid parameters.
     $form_state = (new FormState())
@@ -195,11 +195,11 @@ class PathElementFormTest extends KernelTestBase implements FormInterface {
     // Valid form state.
     $errors = $form_state->getErrors();
     $this->assertEqual(count($errors), 3);
-    $this->assertEqual($errors, array(
-      'required_validate' => t('This path does not exist or you do not have permission to link to %path.', array('%path' => 'user/74')),
-      'required_validate_route' => t('This path does not exist or you do not have permission to link to %path.', array('%path' => 'user/74')),
-      'required_validate_url' => t('This path does not exist or you do not have permission to link to %path.', array('%path' => 'user/74')),
-    ));
+    $this->assertEqual($errors, [
+      'required_validate' => t('This path does not exist or you do not have permission to link to %path.', ['%path' => 'user/74']),
+      'required_validate_route' => t('This path does not exist or you do not have permission to link to %path.', ['%path' => 'user/74']),
+      'required_validate_url' => t('This path does not exist or you do not have permission to link to %path.', ['%path' => 'user/74']),
+    ]);
   }
 
 }
