@@ -4,14 +4,23 @@ namespace Drupal\KernelTests\Core\Entity;
 
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\KernelTests\KernelTestBase;
-use Drupal\user\Entity\Role;
-use Drupal\user\Entity\User;
+use Drupal\Tests\user\Traits\UserCreationTrait;
 
 /**
  * Defines an abstract test base for entity kernel tests.
  */
 abstract class EntityKernelTestBase extends KernelTestBase {
 
+  use UserCreationTrait {
+    checkPermissions as drupalCheckPermissions;
+    createAdminRole as drupalCreateAdminRole;
+    createRole as drupalCreateRole;
+    createUser as drupalCreateUser;
+    grantPermissions as drupalGrantPermissions;
+    setCurrentUser as drupalSetCurrentUser;
+    setUpCurrentUser as drupalSetUpCurrentUser;
+  }
+
   /**
    * Modules to enable.
    *
@@ -26,6 +35,13 @@ abstract class EntityKernelTestBase extends KernelTestBase {
    */
   protected $entityManager;
 
+  /**
+   * The entity type manager service.
+   *
+   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
+   */
+  protected $entityTypeManager;
+
   /**
    * A list of generated identifiers.
    *
@@ -44,6 +60,7 @@ abstract class EntityKernelTestBase extends KernelTestBase {
     parent::setUp();
 
     $this->entityManager = $this->container->get('entity.manager');
+    $this->entityTypeManager = $this->container->get('entity_type.manager');
     $this->state = $this->container->get('state');
 
     $this->installSchema('system', 'sequences');
@@ -70,8 +87,8 @@ abstract class EntityKernelTestBase extends KernelTestBase {
             // enabled in. The comment, node and taxonomy config and the
             // taxonomy_term schema need to be installed before the forum config
             // which in turn needs to be installed before field config.
-            $this->installConfig(['comment', 'node', 'taxonomy']);
             $this->installEntitySchema('taxonomy_term');
+            $this->installConfig(['comment', 'node', 'taxonomy']);
             $this->installConfig(['forum']);
           }
         }
@@ -94,24 +111,7 @@ abstract class EntityKernelTestBase extends KernelTestBase {
    *   The created user entity.
    */
   protected function createUser($values = [], $permissions = []) {
-    if ($permissions) {
-      // Create a new role and apply permissions to it.
-      $role = Role::create([
-        'id' => strtolower($this->randomMachineName(8)),
-        'label' => $this->randomMachineName(8),
-      ]);
-      $role->save();
-      user_role_grant_permissions($role->id(), $permissions);
-      $values['roles'][] = $role->id();
-    }
-
-    $account = User::create($values + [
-      'name' => $this->randomMachineName(),
-      'status' => 1,
-    ]);
-    $account->enforceIsNew();
-    $account->save();
-    return $account;
+    return $this->drupalCreateUser($permissions ?: [], NULL, FALSE, $values ?: []);
   }
 
   /**
@@ -170,6 +170,7 @@ abstract class EntityKernelTestBase extends KernelTestBase {
   protected function refreshServices() {
     $this->container = \Drupal::getContainer();
     $this->entityManager = $this->container->get('entity.manager');
+    $this->entityTypeManager = $this->container->get('entity_type.manager');
     $this->state = $this->container->get('state');
   }
 
